==> kreetingkard-0.4.2.tar.gz: kreetingkard/src/kkapplication.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kcmdlineargs.h>
#include <kdebug.h>

#include "kkapplication.h"
#include "kreetingkard.h"

KKApplication::KKApplication()
 : KUniqueApplication( "KreetingKard" )
{
	KreetingKard* kk = new KreetingKard();
	setMainWidget( kk );
	kk->show();
}


int KKApplication::newInstance()
{
	if( isRestored() )
	{
		RESTORE(KreetingKard);
	}
	else
	{
		KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
		QString filename = args->getOption( "open" );
		if( !filename.isNull() )
		{
			KreetingKard* mainWin = (KreetingKard*)mainWidget();
			kdDebug() << mainWin << endl;
			if( mainWin )
			{
				kdDebug() << filename << endl;
				mainWin->fileOpen( filename, true );
			}
		}
		args->clear();
	}
        
	return KUniqueApplication::newInstance();
}

==> kreetingkard-0.4.3.tar.gz: kreetingkard/src/kkapplication.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kcmdlineargs.h>
#include <kdebug.h>

#include "kkapplication.h"
#include "kreetingkard.h"

KKApplication::KKApplication()
 : KUniqueApplication( "KreetingKard" )
{
	KreetingKard* kk = new KreetingKard();
	setMainWidget( kk );
	kk->show();
}


int KKApplication::newInstance()
{
	if( isRestored() )
	{
		RESTORE(KreetingKard);
	}
	else
	{
		KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
		if( args->count() > 0 )
		{
			QString filename = args->url( args->count() - 1 ).path();
			if( !filename.isNull() )
			{
				KreetingKard* mainWin = (KreetingKard*)mainWidget();
				if( mainWin )
				{
					mainWin->fileOpen( filename, true );
				}
			}
		}
		args->clear();
	}

	return KUniqueApplication::newInstance();
}
